@@ -12,15 +12,16 @@ require( ABSPATH . 'wp-admin/includes/theme-install.php' );
 
 wp_reset_vars( array( 'tab' ) );
 
-if ( ! current_user_can('install_themes') )
+if ( ! current_user_can( 'install_themes' ) ) {
 	wp_die( __( 'Sorry, you are not allowed to install themes on this site.' ) );
+}
 
 if ( is_multisite() && ! is_network_admin() ) {
 	wp_redirect( network_admin_url( 'theme-install.php' ) );
 	exit();
 }
 
-$title = __( 'Add Themes' );
+$title       = __( 'Add Themes' );
 $parent_file = 'themes.php';
 
 if ( ! is_network_admin() ) {
@@ -28,40 +29,50 @@ if ( ! is_network_admin() ) {
 }
 
 $installed_themes = search_theme_directories();
+
+if ( false === $installed_themes ) {
+	$installed_themes = array();
+}
+
 foreach ( $installed_themes as $k => $v ) {
 	if ( false !== strpos( $k, '/' ) ) {
 		unset( $installed_themes[ $k ] );
 	}
 }
 
-wp_localize_script( 'theme', '_wpThemeSettings', array(
-	'themes'   => false,
-	'settings' => array(
-		'isInstall'  => true,
-		'canInstall' => current_user_can( 'install_themes' ),
-		'installURI' => current_user_can( 'install_themes' ) ? self_admin_url( 'theme-install.php' ) : null,
-		'adminUrl'   => parse_url( self_admin_url(), PHP_URL_PATH )
-	),
-	'l10n' => array(
-		'addNew'              => __( 'Add New Theme' ),
-		'search'              => __( 'Search Themes' ),
-		'searchPlaceholder'   => __( 'Search themes...' ), // placeholder (no ellipsis)
-		'upload'              => __( 'Upload Theme' ),
-		'back'                => __( 'Back' ),
-		'error'               => sprintf(
-			/* translators: %s: support forums URL */
-			__( 'An unexpected error occurred. Something may be wrong with WordPress.org or this server&#8217;s configuration. If you continue to have problems, please try the <a href="%s">support forums</a>.' ),
-			__( 'https://wordpress.org/support/' )
+wp_localize_script(
+	'theme',
+	'_wpThemeSettings',
+	array(
+		'themes'          => false,
+		'settings'        => array(
+			'isInstall'  => true,
+			'canInstall' => current_user_can( 'install_themes' ),
+			'installURI' => current_user_can( 'install_themes' ) ? self_admin_url( 'theme-install.php' ) : null,
+			'adminUrl'   => parse_url( self_admin_url(), PHP_URL_PATH ),
 		),
-		'themesFound'         => __( 'Number of Themes found: %d' ),
-		'noThemesFound'       => __( 'No themes found. Try a different search.' ),
-		'collapseSidebar'     => __( 'Collapse Sidebar' ),
-		'expandSidebar'       => __( 'Expand Sidebar' ),
-		/* translators: hidden accessibility text */
-		'selectFeatureFilter' => __( 'Select one or more Theme features to filter by' ),
-	),
-	'installedThemes' => array_keys( $installed_themes ),
-) );
+		'l10n'            => array(
+			'addNew'              => __( 'Add New Theme' ),
+			'search'              => __( 'Search Themes' ),
+			'searchPlaceholder'   => __( 'Search themes...' ), // placeholder (no ellipsis)
+			'upload'              => __( 'Upload Theme' ),
+			'back'                => __( 'Back' ),
+			'error'               => sprintf(
+				/* translators: %s: support forums URL */
+				__( 'An unexpected error occurred. Something may be wrong with WordPress.org or this server&#8217;s configuration. If you continue to have problems, please try the <a href="%s">support forums</a>.' ),
+				__( 'https://wordpress.org/support/' )
+			),
+			'tryAgain'            => __( 'Try Again' ),
+			'themesFound'         => __( 'Number of Themes found: %d' ),
+			'noThemesFound'       => __( 'No themes found. Try a different search.' ),
+			'collapseSidebar'     => __( 'Collapse Sidebar' ),
+			'expandSidebar'       => __( 'Expand Sidebar' ),
+			/* translators: accessibility text */
+			'selectFeatureFilter' => __( 'Select one or more Theme features to filter by' ),
+		),
+		'installedThemes' => array_keys( $installed_themes ),
+	)
+);
 
 wp_enqueue_script( 'theme' );
 wp_enqueue_script( 'updates' );
@@ -71,7 +82,7 @@ if ( $tab ) {
 	 * Fires before each of the tabs are rendered on the Install Themes page.
 	 *
 	 * The dynamic portion of the hook name, `$tab`, refers to the current
-	 * theme install tab. Possible values are 'dashboard', 'search', 'upload',
+	 * theme installation tab. Possible values are 'dashboard', 'search', 'upload',
 	 * 'featured', 'new', or 'updated'.
 	 *
 	 * @since 2.8.0
@@ -81,46 +92,51 @@ if ( $tab ) {
 
 $help_overview =
 	'<p>' . sprintf(
-			/* translators: %s: Theme Directory URL */
+		/* translators: %s: Theme Directory URL */
 			__( 'You can find additional themes for your site by using the Theme Browser/Installer on this screen, which will display themes from the <a href="%s">WordPress Theme Directory</a>. These themes are designed and developed by third parties, are available free of charge, and are compatible with the license WordPress uses.' ),
-			__( 'https://wordpress.org/themes/' )
-		) . '</p>' .
+		__( 'https://wordpress.org/themes/' )
+	) . '</p>' .
 	'<p>' . __( 'You can Search for themes by keyword, author, or tag, or can get more specific and search by criteria listed in the feature filter.' ) . ' <span id="live-search-desc">' . __( 'The search results will be updated as you type.' ) . '</span></p>' .
 	'<p>' . __( 'Alternately, you can browse the themes that are Featured, Popular, or Latest. When you find a theme you like, you can preview it or install it.' ) . '</p>' .
 	'<p>' . sprintf(
-			/* translators: %s: /wp-content/themes */
+		/* translators: %s: /wp-content/themes */
 			__( 'You can Upload a theme manually if you have already downloaded its ZIP archive onto your computer (make sure it is from a trusted and original source). You can also do it the old-fashioned way and copy a downloaded theme&#8217;s folder via FTP into your %s directory.' ),
-			'<code>/wp-content/themes</code>'
-		) . '</p>';
+		'<code>/wp-content/themes</code>'
+	) . '</p>';
 
-get_current_screen()->add_help_tab( array(
-	'id'      => 'overview',
-	'title'   => __('Overview'),
-	'content' => $help_overview
-) );
-
-$help_installing =
-	'<p>' . __('Once you have generated a list of themes, you can preview and install any of them. Click on the thumbnail of the theme you&#8217;re interested in previewing. It will open up in a full-screen Preview page to give you a better idea of how that theme will look.') . '</p>' .
-	'<p>' . __('To install the theme so you can preview it with your site&#8217;s content and customize its theme options, click the "Install" button at the top of the left-hand pane. The theme files will be downloaded to your website automatically. When this is complete, the theme is now available for activation, which you can do by clicking the "Activate" link, or by navigating to your Manage Themes screen and clicking the "Live Preview" link under any installed theme&#8217;s thumbnail image.') . '</p>';
-
-get_current_screen()->add_help_tab( array(
-	'id'      => 'installing',
-	'title'   => __('Previewing and Installing'),
-	'content' => $help_installing
-) );
-
-get_current_screen()->set_help_sidebar(
-	'<p><strong>' . __('For more information:') . '</strong></p>' .
-	'<p>' . __('<a href="https://codex.wordpress.org/Using_Themes#Adding_New_Themes">Documentation on Adding New Themes</a>') . '</p>' .
-	'<p>' . __('<a href="https://wordpress.org/support/">Support Forums</a>') . '</p>'
+get_current_screen()->add_help_tab(
+	array(
+		'id'      => 'overview',
+		'title'   => __( 'Overview' ),
+		'content' => $help_overview,
+	)
 );
 
-include(ABSPATH . 'wp-admin/admin-header.php');
+$help_installing =
+	'<p>' . __( 'Once you have generated a list of themes, you can preview and install any of them. Click on the thumbnail of the theme you&#8217;re interested in previewing. It will open up in a full-screen Preview page to give you a better idea of how that theme will look.' ) . '</p>' .
+	'<p>' . __( 'To install the theme so you can preview it with your site&#8217;s content and customize its theme options, click the "Install" button at the top of the left-hand pane. The theme files will be downloaded to your website automatically. When this is complete, the theme is now available for activation, which you can do by clicking the "Activate" link, or by navigating to your Manage Themes screen and clicking the "Live Preview" link under any installed theme&#8217;s thumbnail image.' ) . '</p>';
+
+get_current_screen()->add_help_tab(
+	array(
+		'id'      => 'installing',
+		'title'   => __( 'Previewing and Installing' ),
+		'content' => $help_installing,
+	)
+);
+
+get_current_screen()->set_help_sidebar(
+	'<p><strong>' . __( 'For more information:' ) . '</strong></p>' .
+	'<p>' . __( '<a href="https://codex.wordpress.org/Using_Themes#Adding_New_Themes">Documentation on Adding New Themes</a>' ) . '</p>' .
+	'<p>' . __( '<a href="https://wordpress.org/support/">Support Forums</a>' ) . '</p>'
+);
+
+include( ABSPATH . 'wp-admin/admin-header.php' );
 
 ?>
 <div class="wrap">
-	<h1><?php
-	echo esc_html( $title );
+	<h1 class="wp-heading-inline"><?php echo esc_html( $title ); ?></h1>
+
+	<?php
 
 	/**
 	 * Filters the tabs shown on the Add Themes screen.
@@ -129,13 +145,16 @@ include(ABSPATH . 'wp-admin/admin-header.php');
 	 *
 	 * @since 2.8.0
 	 *
-	 * @param array $tabs The tabs shown on the Add Themes screen. Default is 'upload'.
+	 * @param string[] $tabs Associative array of the tabs shown on the Add Themes screen. Default is 'upload'.
 	 */
 	$tabs = apply_filters( 'install_themes_tabs', array( 'upload' => __( 'Upload Theme' ) ) );
 	if ( ! empty( $tabs['upload'] ) && current_user_can( 'upload_themes' ) ) {
 		echo ' <button type="button" class="upload-view-toggle page-title-action hide-if-no-js" aria-expanded="false">' . __( 'Upload Theme' ) . '</button>';
 	}
-	?></h1>
+	?>
+
+	<hr class="wp-header-end">
+
 	<div class="error hide-if-js">
 		<p><?php _e( 'The Theme Installer screen requires JavaScript.' ); ?></p>
 	</div>
@@ -160,7 +179,7 @@ include(ABSPATH . 'wp-admin/admin-header.php');
 
 		<button type="button" class="button drawer-toggle" aria-expanded="false"><?php _e( 'Feature Filter' ); ?></button>
 
-		<div class="search-form"></div>
+		<form class="search-form"></form>
 
 		<div class="favorites-form">
 			<?php
@@ -188,7 +207,7 @@ include(ABSPATH . 'wp-admin/admin-header.php');
 				<button type="button" class="clear-filters button" aria-label="<?php esc_attr_e( 'Clear current filters' ); ?>"><?php _e( 'Clear' ); ?></button>
 			</div>
 		<?php
-		$feature_list = get_theme_feature_list();
+		$feature_list = get_theme_feature_list( false ); // Use the core list, rather than the .org API, due to inconsistencies and to ensure tags are translated.
 		foreach ( $feature_list as $feature_name => $features ) {
 			echo '<fieldset class="filter-group">';
 			$feature_name = esc_html( $feature_name );
@@ -197,7 +216,7 @@ include(ABSPATH . 'wp-admin/admin-header.php');
 			foreach ( $features as $feature => $feature_name ) {
 				$feature = esc_attr( $feature );
 				echo '<input type="checkbox" id="filter-id-' . $feature . '" value="' . $feature . '" /> ';
-				echo '<label for="filter-id-' . $feature . '">' . $feature_name . '</label><br>';
+				echo '<label for="filter-id-' . $feature . '">' . $feature_name . '</label>';
 			}
 			echo '</div>';
 			echo '</fieldset>';
@@ -227,7 +246,7 @@ if ( $tab ) {
 	 * Fires at the top of each of the tabs on the Install Themes page.
 	 *
 	 * The dynamic portion of the hook name, `$tab`, refers to the current
-	 * theme install tab. Possible values are 'dashboard', 'search', 'upload',
+	 * theme installation tab. Possible values are 'dashboard', 'search', 'upload',
 	 * 'featured', 'new', or 'updated'.
 	 *
 	 * @since 2.8.0
@@ -254,30 +273,33 @@ if ( $tab ) {
 		printf( __( 'By %s' ), '{{ data.author }}' );
 		?>
 	</div>
-	<h3 class="theme-name">{{ data.name }}</h3>
 
-	<div class="theme-actions">
-		<# if ( data.installed ) { #>
-			<?php
-			/* translators: %s: Theme name */
-			$aria_label = sprintf( _x( 'Activate %s', 'theme' ), '{{ data.name }}' );
-			?>
-			<# if ( data.activate_url ) { #>
-				<a class="button button-primary activate" href="{{ data.activate_url }}" aria-label="<?php echo esc_attr( $aria_label ); ?>"><?php _e( 'Activate' ); ?></a>
-			<# } #>
-			<# if ( data.customize_url ) { #>
-				<a class="button load-customize" href="{{ data.customize_url }}"><?php _e( 'Live Preview' ); ?></a>
+	<div class="theme-id-container">
+		<h3 class="theme-name">{{ data.name }}</h3>
+
+		<div class="theme-actions">
+			<# if ( data.installed ) { #>
+				<?php
+				/* translators: %s: Theme name */
+				$aria_label = sprintf( _x( 'Activate %s', 'theme' ), '{{ data.name }}' );
+				?>
+				<# if ( data.activate_url ) { #>
+					<a class="button button-primary activate" href="{{ data.activate_url }}" aria-label="<?php echo esc_attr( $aria_label ); ?>"><?php _e( 'Activate' ); ?></a>
+				<# } #>
+				<# if ( data.customize_url ) { #>
+					<a class="button load-customize" href="{{ data.customize_url }}"><?php _e( 'Live Preview' ); ?></a>
+				<# } else { #>
+					<button class="button preview install-theme-preview"><?php _e( 'Preview' ); ?></button>
+				<# } #>
 			<# } else { #>
+				<?php
+				/* translators: %s: Theme name */
+				$aria_label = sprintf( __( 'Install %s' ), '{{ data.name }}' );
+				?>
+				<a class="button button-primary theme-install" data-name="{{ data.name }}" data-slug="{{ data.id }}" href="{{ data.install_url }}" aria-label="<?php echo esc_attr( $aria_label ); ?>"><?php _e( 'Install' ); ?></a>
 				<button class="button preview install-theme-preview"><?php _e( 'Preview' ); ?></button>
 			<# } #>
-		<# } else { #>
-			<?php
-			/* translators: %s: Theme name */
-			$aria_label = sprintf( __( 'Install %s' ), '{{ data.name }}' );
-			?>
-			<a class="button button-primary theme-install" data-name="{{ data.name }}" data-slug="{{ data.id }}" href="{{ data.install_url }}" aria-label="<?php echo esc_attr( $aria_label ); ?>"><?php _e( 'Install' ); ?></a>
-			<button class="button preview install-theme-preview"><?php _e( 'Preview' ); ?></button>
-		<# } #>
+		</div>
 	</div>
 
 	<# if ( data.installed ) { #>
@@ -289,8 +311,8 @@ if ( $tab ) {
 	<div class="wp-full-overlay-sidebar">
 		<div class="wp-full-overlay-header">
 			<button class="close-full-overlay"><span class="screen-reader-text"><?php _e( 'Close' ); ?></span></button>
-			<button class="previous-theme"><span class="screen-reader-text"><?php _ex( 'Previous', 'Button label for a theme' ); ?></span></button>
-			<button class="next-theme"><span class="screen-reader-text"><?php _ex( 'Next', 'Button label for a theme' ); ?></span></button>
+			<button class="previous-theme"><span class="screen-reader-text"><?php _e( 'Previous theme' ); ?></span></button>
+			<button class="next-theme"><span class="screen-reader-text"><?php _e( 'Next theme' ); ?></span></button>
 			<# if ( data.installed ) { #>
 				<a class="button button-primary activate" href="{{ data.activate_url }}"><?php _e( 'Activate' ); ?></a>
 			<# } else { #>
@@ -344,4 +366,4 @@ if ( $tab ) {
 wp_print_request_filesystem_credentials_modal();
 wp_print_admin_notice_templates();
 
-include(ABSPATH . 'wp-admin/admin-footer.php');
+include( ABSPATH . 'wp-admin/admin-footer.php' );
