@@ -11,35 +11,35 @@ require_once( dirname( __FILE__ ) . '/admin.php' );
 
 if ( ! current_user_can( 'switch_themes' ) && ! current_user_can( 'edit_theme_options' ) ) {
 	wp_die(
-		'<h1>' . __( 'Cheatin&#8217; uh?' ) . '</h1>' .
+		'<h1>' . __( 'You need a higher level of permission.' ) . '</h1>' .
 		'<p>' . __( 'Sorry, you are not allowed to edit theme options on this site.' ) . '</p>',
 		403
 	);
 }
 
-if ( current_user_can( 'switch_themes' ) && isset($_GET['action'] ) ) {
+if ( current_user_can( 'switch_themes' ) && isset( $_GET['action'] ) ) {
 	if ( 'activate' == $_GET['action'] ) {
-		check_admin_referer('switch-theme_' . $_GET['stylesheet']);
+		check_admin_referer( 'switch-theme_' . $_GET['stylesheet'] );
 		$theme = wp_get_theme( $_GET['stylesheet'] );
 
 		if ( ! $theme->exists() || ! $theme->is_allowed() ) {
 			wp_die(
-				'<h1>' . __( 'Cheatin&#8217; uh?' ) . '</h1>' .
+				'<h1>' . __( 'Something went wrong.' ) . '</h1>' .
 				'<p>' . __( 'The requested theme does not exist.' ) . '</p>',
 				403
 			);
 		}
 
 		switch_theme( $theme->get_stylesheet() );
-		wp_redirect( admin_url('themes.php?activated=true') );
+		wp_redirect( admin_url( 'themes.php?activated=true' ) );
 		exit;
 	} elseif ( 'delete' == $_GET['action'] ) {
-		check_admin_referer('delete-theme_' . $_GET['stylesheet']);
+		check_admin_referer( 'delete-theme_' . $_GET['stylesheet'] );
 		$theme = wp_get_theme( $_GET['stylesheet'] );
 
 		if ( ! current_user_can( 'delete_themes' ) ) {
 			wp_die(
-				'<h1>' . __( 'Cheatin&#8217; uh?' ) . '</h1>' .
+				'<h1>' . __( 'You need a higher level of permission.' ) . '</h1>' .
 				'<p>' . __( 'Sorry, you are not allowed to delete this item.' ) . '</p>',
 				403
 			);
@@ -47,7 +47,7 @@ if ( current_user_can( 'switch_themes' ) && isset($_GET['action'] ) ) {
 
 		if ( ! $theme->exists() ) {
 			wp_die(
-				'<h1>' . __( 'Cheatin&#8217; uh?' ) . '</h1>' .
+				'<h1>' . __( 'Something went wrong.' ) . '</h1>' .
 				'<p>' . __( 'The requested theme does not exist.' ) . '</p>',
 				403
 			);
@@ -64,12 +64,12 @@ if ( current_user_can( 'switch_themes' ) && isset($_GET['action'] ) ) {
 	}
 }
 
-$title = __('Manage Themes');
+$title       = __( 'Manage Themes' );
 $parent_file = 'themes.php';
 
 // Help tab: Overview
 if ( current_user_can( 'switch_themes' ) ) {
-	$help_overview  = '<p>' . __( 'This screen is used for managing your installed themes. Aside from the default theme(s) included with your WordPress installation, themes are designed and developed by third parties.' ) . '</p>' .
+	$help_overview = '<p>' . __( 'This screen is used for managing your installed themes. Aside from the default theme(s) included with your WordPress installation, themes are designed and developed by third parties.' ) . '</p>' .
 		'<p>' . __( 'From this screen you can:' ) . '</p>' .
 		'<ul><li>' . __( 'Hover or tap to see Activate and Live Preview buttons' ) . '</li>' .
 		'<li>' . __( 'Click on the theme to see the theme name, version, author, description, tags, and the Delete link' ) . '</li>' .
@@ -77,40 +77,46 @@ if ( current_user_can( 'switch_themes' ) ) {
 		'<p>' . __( 'The current theme is displayed highlighted as the first theme.' ) . '</p>' .
 		'<p>' . __( 'The search for installed themes will search for terms in their name, description, author, or tag.' ) . ' <span id="live-search-desc">' . __( 'The search results will be updated as you type.' ) . '</span></p>';
 
-	get_current_screen()->add_help_tab( array(
-		'id'      => 'overview',
-		'title'   => __( 'Overview' ),
-		'content' => $help_overview
-	) );
+	get_current_screen()->add_help_tab(
+		array(
+			'id'      => 'overview',
+			'title'   => __( 'Overview' ),
+			'content' => $help_overview,
+		)
+	);
 } // switch_themes
 
 // Help tab: Adding Themes
 if ( current_user_can( 'install_themes' ) ) {
 	if ( is_multisite() ) {
-		$help_install = '<p>' . __('Installing themes on Multisite can only be done from the Network Admin section.') . '</p>';
+		$help_install = '<p>' . __( 'Installing themes on Multisite can only be done from the Network Admin section.' ) . '</p>';
 	} else {
-		$help_install = '<p>' . sprintf( __('If you would like to see more themes to choose from, click on the &#8220;Add New&#8221; button and you will be able to browse or search for additional themes from the <a href="%s">WordPress Theme Directory</a>. Themes in the WordPress Theme Directory are designed and developed by third parties, and are compatible with the license WordPress uses. Oh, and they&#8217;re free!'), __( 'https://wordpress.org/themes/' ) ) . '</p>';
+		$help_install = '<p>' . sprintf( __( 'If you would like to see more themes to choose from, click on the &#8220;Add New&#8221; button and you will be able to browse or search for additional themes from the <a href="%s">WordPress Theme Directory</a>. Themes in the WordPress Theme Directory are designed and developed by third parties, and are compatible with the license WordPress uses. Oh, and they&#8217;re free!' ), __( 'https://wordpress.org/themes/' ) ) . '</p>';
 	}
 
-	get_current_screen()->add_help_tab( array(
-		'id'      => 'adding-themes',
-		'title'   => __('Adding Themes'),
-		'content' => $help_install
-	) );
+	get_current_screen()->add_help_tab(
+		array(
+			'id'      => 'adding-themes',
+			'title'   => __( 'Adding Themes' ),
+			'content' => $help_install,
+		)
+	);
 } // install_themes
 
 // Help tab: Previewing and Customizing
 if ( current_user_can( 'edit_theme_options' ) && current_user_can( 'customize' ) ) {
 	$help_customize =
-		'<p>' . __( 'Tap or hover on any theme then click the Live Preview button to see a live preview of that theme and change theme options in a separate, full-screen view. You can also find a Live Preview button at the bottom of the theme details screen. Any installed theme can be previewed and customized in this way.' ) . '</p>'.
-		'<p>' . __( 'The theme being previewed is fully interactive &mdash; navigate to different pages to see how the theme handles posts, archives, and other page templates. The settings may differ depending on what theme features the theme being previewed supports. To accept the new settings and activate the theme all in one step, click the Save &amp; Activate button above the menu.' ) . '</p>' .
+		'<p>' . __( 'Tap or hover on any theme then click the Live Preview button to see a live preview of that theme and change theme options in a separate, full-screen view. You can also find a Live Preview button at the bottom of the theme details screen. Any installed theme can be previewed and customized in this way.' ) . '</p>' .
+		'<p>' . __( 'The theme being previewed is fully interactive &mdash; navigate to different pages to see how the theme handles posts, archives, and other page templates. The settings may differ depending on what theme features the theme being previewed supports. To accept the new settings and activate the theme all in one step, click the Publish &amp; Activate button above the menu.' ) . '</p>' .
 		'<p>' . __( 'When previewing on smaller monitors, you can use the collapse icon at the bottom of the left-hand pane. This will hide the pane, giving you more room to preview your site in the new theme. To bring the pane back, click on the collapse icon again.' ) . '</p>';
 
-	get_current_screen()->add_help_tab( array(
-		'id'		=> 'customize-preview-themes',
-		'title'		=> __( 'Previewing and Customizing' ),
-		'content'	=> $help_customize
-	) );
+	get_current_screen()->add_help_tab(
+		array(
+			'id'      => 'customize-preview-themes',
+			'title'   => __( 'Previewing and Customizing' ),
+			'content' => $help_customize,
+		)
+	);
 } // edit_theme_options && customize
 
 get_current_screen()->set_help_sidebar(
@@ -126,53 +132,70 @@ if ( current_user_can( 'switch_themes' ) ) {
 }
 wp_reset_vars( array( 'theme', 'search' ) );
 
-wp_localize_script( 'theme', '_wpThemeSettings', array(
-	'themes'   => $themes,
-	'settings' => array(
-		'canInstall'    => ( ! is_multisite() && current_user_can( 'install_themes' ) ),
-		'installURI'    => ( ! is_multisite() && current_user_can( 'install_themes' ) ) ? admin_url( 'theme-install.php' ) : null,
-		'confirmDelete' => __( "Are you sure you want to delete this theme?\n\nClick 'Cancel' to go back, 'OK' to confirm the delete." ),
-		'adminUrl'      => parse_url( admin_url(), PHP_URL_PATH ),
-	),
- 	'l10n' => array(
- 		'addNew'            => __( 'Add New Theme' ),
- 		'search'            => __( 'Search Installed Themes' ),
- 		'searchPlaceholder' => __( 'Search installed themes...' ), // placeholder (no ellipsis)
-		'themesFound'       => __( 'Number of Themes found: %d' ),
-		'noThemesFound'     => __( 'No themes found. Try a different search.' ),
-  	),
-) );
+wp_localize_script(
+	'theme',
+	'_wpThemeSettings',
+	array(
+		'themes'   => $themes,
+		'settings' => array(
+			'canInstall'    => ( ! is_multisite() && current_user_can( 'install_themes' ) ),
+			'installURI'    => ( ! is_multisite() && current_user_can( 'install_themes' ) ) ? admin_url( 'theme-install.php' ) : null,
+			'confirmDelete' => __( "Are you sure you want to delete this theme?\n\nClick 'Cancel' to go back, 'OK' to confirm the delete." ),
+			'adminUrl'      => parse_url( admin_url(), PHP_URL_PATH ),
+		),
+		'l10n'     => array(
+			'addNew'            => __( 'Add New Theme' ),
+			'search'            => __( 'Search Installed Themes' ),
+			'searchPlaceholder' => __( 'Search installed themes...' ), // placeholder (no ellipsis)
+			'themesFound'       => __( 'Number of Themes found: %d' ),
+			'noThemesFound'     => __( 'No themes found. Try a different search.' ),
+		),
+	)
+);
 
 add_thickbox();
 wp_enqueue_script( 'theme' );
 wp_enqueue_script( 'updates' );
-wp_enqueue_script( 'customize-loader' );
 
 require_once( ABSPATH . 'wp-admin/admin-header.php' );
 ?>
 
 <div class="wrap">
-	<h1><?php esc_html_e( 'Themes' ); ?>
-		<span class="title-count theme-count"><?php echo count( $themes ); ?></span>
+	<h1 class="wp-heading-inline"><?php esc_html_e( 'Themes' ); ?>
+		<span class="title-count theme-count"><?php echo ! empty( $_GET['search'] ) ? __( '&hellip;' ) : count( $themes ); ?></span>
+	</h1>
+
 	<?php if ( ! is_multisite() && current_user_can( 'install_themes' ) ) : ?>
 		<a href="<?php echo admin_url( 'theme-install.php' ); ?>" class="hide-if-no-js page-title-action"><?php echo esc_html_x( 'Add New', 'Add new theme' ); ?></a>
 	<?php endif; ?>
-	</h1>
+
+	<form class="search-form"></form>
+
+	<hr class="wp-header-end">
 <?php
-if ( ! validate_current_theme() || isset( $_GET['broken'] ) ) : ?>
-<div id="message1" class="updated notice is-dismissible"><p><?php _e('The active theme is broken. Reverting to the default theme.'); ?></p></div>
-<?php elseif ( isset($_GET['activated']) ) :
-		if ( isset( $_GET['previewed'] ) ) { ?>
+if ( ! validate_current_theme() || isset( $_GET['broken'] ) ) {
+	?>
+	<div id="message1" class="updated notice is-dismissible"><p><?php _e( 'The active theme is broken. Reverting to the default theme.' ); ?></p></div>
+	<?php
+} elseif ( isset( $_GET['activated'] ) ) {
+	if ( isset( $_GET['previewed'] ) ) {
+		?>
 		<div id="message2" class="updated notice is-dismissible"><p><?php _e( 'Settings saved and theme activated.' ); ?> <a href="<?php echo home_url( '/' ); ?>"><?php _e( 'Visit site' ); ?></a></p></div>
-		<?php } else { ?>
-<div id="message2" class="updated notice is-dismissible"><p><?php _e( 'New theme activated.' ); ?> <a href="<?php echo home_url( '/' ); ?>"><?php _e( 'Visit site' ); ?></a></p></div><?php
-		}
-	elseif ( isset($_GET['deleted']) ) : ?>
-<div id="message3" class="updated notice is-dismissible"><p><?php _e('Theme deleted.') ?></p></div>
-<?php elseif ( isset( $_GET['delete-active-child'] ) ) : ?>
+		<?php
+	} else {
+		?>
+		<div id="message2" class="updated notice is-dismissible"><p><?php _e( 'New theme activated.' ); ?> <a href="<?php echo home_url( '/' ); ?>"><?php _e( 'Visit site' ); ?></a></p></div>
+		<?php
+	}
+} elseif ( isset( $_GET['deleted'] ) ) {
+	?>
+	<div id="message3" class="updated notice is-dismissible"><p><?php _e( 'Theme deleted.' ); ?></p></div>
+	<?php
+} elseif ( isset( $_GET['delete-active-child'] ) ) {
+	?>
 	<div id="message4" class="error"><p><?php _e( 'You cannot delete a theme while it has an active child theme.' ); ?></p></div>
-<?php
-endif;
+	<?php
+}
 
 $ct = wp_get_theme();
 
@@ -188,48 +211,57 @@ if ( ! $ct->errors() || ( 1 == count( $ct->errors()->get_error_codes() )
 
 	// Pretend you didn't see this.
 	$current_theme_actions = array();
-	if ( is_array( $submenu ) && isset( $submenu['themes.php'] ) ) {
-		foreach ( (array) $submenu['themes.php'] as $item) {
-			$class = '';
-			if ( 'themes.php' == $item[2] || 'theme-editor.php' == $item[2] || 0 === strpos( $item[2], 'customize.php' ) )
-				continue;
-			// 0 = name, 1 = capability, 2 = file
-			if ( ( strcmp($self, $item[2]) == 0 && empty($parent_file)) || ($parent_file && ($item[2] == $parent_file)) )
-				$class = ' current';
-			if ( !empty($submenu[$item[2]]) ) {
-				$submenu[$item[2]] = array_values($submenu[$item[2]]); // Re-index.
-				$menu_hook = get_plugin_page_hook($submenu[$item[2]][0][2], $item[2]);
-				if ( file_exists(WP_PLUGIN_DIR . "/{$submenu[$item[2]][0][2]}") || !empty($menu_hook))
-					$current_theme_actions[] = "<a class='button$class' href='admin.php?page={$submenu[$item[2]][0][2]}'>{$item[0]}</a>";
-				else
-					$current_theme_actions[] = "<a class='button$class' href='{$submenu[$item[2]][0][2]}'>{$item[0]}</a>";
-			} elseif ( ! empty( $item[2] ) && current_user_can( $item[1] ) ) {
-				$menu_file = $item[2];
+if ( is_array( $submenu ) && isset( $submenu['themes.php'] ) ) {
+	foreach ( (array) $submenu['themes.php'] as $item ) {
+		$class = '';
+		if ( 'themes.php' == $item[2] || 'theme-editor.php' == $item[2] || 0 === strpos( $item[2], 'customize.php' ) ) {
+			continue;
+		}
+		// 0 = name, 1 = capability, 2 = file
+		if ( ( strcmp( $self, $item[2] ) == 0 && empty( $parent_file ) ) || ( $parent_file && ( $item[2] == $parent_file ) ) ) {
+			$class = ' current';
+		}
+		if ( ! empty( $submenu[ $item[2] ] ) ) {
+			$submenu[ $item[2] ] = array_values( $submenu[ $item[2] ] ); // Re-index.
+			$menu_hook           = get_plugin_page_hook( $submenu[ $item[2] ][0][2], $item[2] );
+			if ( file_exists( WP_PLUGIN_DIR . "/{$submenu[$item[2]][0][2]}" ) || ! empty( $menu_hook ) ) {
+				$current_theme_actions[] = "<a class='button$class' href='admin.php?page={$submenu[$item[2]][0][2]}'>{$item[0]}</a>";
+			} else {
+				$current_theme_actions[] = "<a class='button$class' href='{$submenu[$item[2]][0][2]}'>{$item[0]}</a>";
+			}
+		} elseif ( ! empty( $item[2] ) && current_user_can( $item[1] ) ) {
+			$menu_file = $item[2];
 
-				if ( current_user_can( 'customize' ) ) {
-					if ( 'custom-header' === $menu_file ) {
-						$current_theme_actions[] = "<a class='button hide-if-no-customize$class' href='customize.php?autofocus[control]=header_image'>{$item[0]}</a>";
-					} elseif ( 'custom-background' === $menu_file ) {
-						$current_theme_actions[] = "<a class='button hide-if-no-customize$class' href='customize.php?autofocus[control]=background_image'>{$item[0]}</a>";
-					}
+			if ( current_user_can( 'customize' ) ) {
+				if ( 'custom-header' === $menu_file ) {
+					$current_theme_actions[] = "<a class='button hide-if-no-customize$class' href='customize.php?autofocus[control]=header_image'>{$item[0]}</a>";
+				} elseif ( 'custom-background' === $menu_file ) {
+					$current_theme_actions[] = "<a class='button hide-if-no-customize$class' href='customize.php?autofocus[control]=background_image'>{$item[0]}</a>";
 				}
+			}
 
-				if ( false !== ( $pos = strpos( $menu_file, '?' ) ) ) {
-					$menu_file = substr( $menu_file, 0, $pos );
-				}
+			if ( false !== ( $pos = strpos( $menu_file, '?' ) ) ) {
+				$menu_file = substr( $menu_file, 0, $pos );
+			}
 
-				if ( file_exists( ABSPATH . "wp-admin/$menu_file" ) ) {
-					$current_theme_actions[] = "<a class='button$class' href='{$item[2]}'>{$item[0]}</a>";
-				} else {
-					$current_theme_actions[] = "<a class='button$class' href='themes.php?page={$item[2]}'>{$item[0]}</a>";
-				}
+			if ( file_exists( ABSPATH . "wp-admin/$menu_file" ) ) {
+				$current_theme_actions[] = "<a class='button$class' href='{$item[2]}'>{$item[0]}</a>";
+			} else {
+				$current_theme_actions[] = "<a class='button$class' href='themes.php?page={$item[2]}'>{$item[0]}</a>";
 			}
 		}
 	}
+}
 
 ?>
 
-<div class="theme-browser">
+<?php
+$class_name = 'theme-browser';
+if ( ! empty( $_GET['search'] ) ) {
+	$class_name .= ' search-loading';
+}
+?>
+<div class="<?php echo esc_attr( $class_name ); ?>">
 	<div class="themes wp-clearfix">
 
 <?php
@@ -240,8 +272,13 @@ if ( ! $ct->errors() || ( 1 == count( $ct->errors()->get_error_codes() )
 foreach ( $themes as $theme ) :
 	$aria_action = esc_attr( $theme['id'] . '-action' );
 	$aria_name   = esc_attr( $theme['id'] . '-name' );
+
+	$active_class = '';
+	if ( $theme['active'] ) {
+		$active_class = ' active';
+	}
 	?>
-<div class="theme<?php if ( $theme['active'] ) echo ' active'; ?>" tabindex="0" aria-describedby="<?php echo $aria_action . ' ' . $aria_name; ?>">
+<div class="theme<?php echo $active_class; ?>" tabindex="0" aria-describedby="<?php echo $aria_action . ' ' . $aria_name; ?>">
 	<?php if ( ! empty( $theme['screenshot'][0] ) ) { ?>
 		<div class="theme-screenshot">
 			<img src="<?php echo $theme['screenshot'][0]; ?>" alt="" />
@@ -263,60 +300,61 @@ foreach ( $themes as $theme ) :
 	<span class="more-details" id="<?php echo $aria_action; ?>"><?php _e( 'Theme Details' ); ?></span>
 	<div class="theme-author"><?php printf( __( 'By %s' ), $theme['author'] ); ?></div>
 
-	<?php if ( $theme['active'] ) { ?>
-		<h2 class="theme-name" id="<?php echo $aria_name; ?>">
+	<div class="theme-id-container">
+		<?php if ( $theme['active'] ) { ?>
+			<h2 class="theme-name" id="<?php echo $aria_name; ?>">
+				<?php
+				/* translators: %s: theme name */
+				printf( __( '<span>Active:</span> %s' ), $theme['name'] );
+				?>
+			</h2>
+		<?php } else { ?>
+			<h2 class="theme-name" id="<?php echo $aria_name; ?>"><?php echo $theme['name']; ?></h2>
+		<?php } ?>
+
+		<div class="theme-actions">
+		<?php if ( $theme['active'] ) { ?>
+			<?php if ( $theme['actions']['customize'] && current_user_can( 'edit_theme_options' ) && current_user_can( 'customize' ) ) { ?>
+				<a class="button button-primary customize load-customize hide-if-no-customize" href="<?php echo $theme['actions']['customize']; ?>"><?php _e( 'Customize' ); ?></a>
+			<?php } ?>
+		<?php } else { ?>
 			<?php
-			/* translators: %s: theme name */
-			printf( __( '<span>Active:</span> %s' ), $theme['name'] );
+			/* translators: %s: Theme name */
+			$aria_label = sprintf( _x( 'Activate %s', 'theme' ), '{{ data.name }}' );
 			?>
-		</h2>
-	<?php } else { ?>
-		<h2 class="theme-name" id="<?php echo $aria_name; ?>"><?php echo $theme['name']; ?></h2>
-	<?php } ?>
-
-	<div class="theme-actions">
-
-	<?php if ( $theme['active'] ) { ?>
-		<?php if ( $theme['actions']['customize'] && current_user_can( 'edit_theme_options' ) && current_user_can( 'customize' ) ) { ?>
-			<a class="button button-primary customize load-customize hide-if-no-customize" href="<?php echo $theme['actions']['customize']; ?>"><?php _e( 'Customize' ); ?></a>
+			<a class="button activate" href="<?php echo $theme['actions']['activate']; ?>" aria-label="<?php echo esc_attr( $aria_label ); ?>"><?php _e( 'Activate' ); ?></a>
+			<?php if ( current_user_can( 'edit_theme_options' ) && current_user_can( 'customize' ) ) { ?>
+				<a class="button button-primary load-customize hide-if-no-customize" href="<?php echo $theme['actions']['customize']; ?>"><?php _e( 'Live Preview' ); ?></a>
+			<?php } ?>
 		<?php } ?>
-	<?php } else { ?>
-		<?php
-		/* translators: %s: Theme name */
-		$aria_label = sprintf( _x( 'Activate %s', 'theme' ), '{{ data.name }}' );
-		?>
-		<a class="button activate" href="<?php echo $theme['actions']['activate']; ?>" aria-label="<?php echo esc_attr( $aria_label ); ?>"><?php _e( 'Activate' ); ?></a>
-		<?php if ( current_user_can( 'edit_theme_options' ) && current_user_can( 'customize' ) ) { ?>
-			<a class="button button-primary load-customize hide-if-no-customize" href="<?php echo $theme['actions']['customize']; ?>"><?php _e( 'Live Preview' ); ?></a>
-		<?php } ?>
-	<?php } ?>
 
+		</div>
 	</div>
 </div>
 <?php endforeach; ?>
 	</div>
 </div>
-<div class="theme-overlay"></div>
+<div class="theme-overlay" tabindex="0" role="dialog" aria-label="<?php esc_attr_e( 'Theme Details' ); ?>"></div>
 
 <p class="no-themes"><?php _e( 'No themes found. Try a different search.' ); ?></p>
 
 <?php
 // List broken themes, if any.
-if ( ! is_multisite() && current_user_can('edit_themes') && $broken_themes = wp_get_themes( array( 'errors' => true ) ) ) {
-?>
+if ( ! is_multisite() && current_user_can( 'edit_themes' ) && $broken_themes = wp_get_themes( array( 'errors' => true ) ) ) {
+	?>
 
 <div class="broken-themes">
-<h3><?php _e('Broken Themes'); ?></h3>
+<h3><?php _e( 'Broken Themes' ); ?></h3>
 <p><?php _e( 'The following themes are installed but incomplete.' ); ?></p>
 
-<?php
-$can_delete = current_user_can( 'delete_themes' );
-$can_install = current_user_can( 'install_themes' );
-?>
+	<?php
+	$can_delete  = current_user_can( 'delete_themes' );
+	$can_install = current_user_can( 'install_themes' );
+	?>
 <table>
 	<tr>
-		<th><?php _ex('Name', 'theme name'); ?></th>
-		<th><?php _e('Description'); ?></th>
+		<th><?php _ex( 'Name', 'theme name' ); ?></th>
+		<th><?php _e( 'Description' ); ?></th>
 		<?php if ( $can_delete ) { ?>
 			<td></td>
 		<?php } ?>
@@ -331,10 +369,13 @@ $can_install = current_user_can( 'install_themes' );
 			<?php
 			if ( $can_delete ) {
 				$stylesheet = $broken_theme->get_stylesheet();
-				$delete_url = add_query_arg( array(
-					'action'     => 'delete',
-					'stylesheet' => urlencode( $stylesheet ),
-				), admin_url( 'themes.php' ) );
+				$delete_url = add_query_arg(
+					array(
+						'action'     => 'delete',
+						'stylesheet' => urlencode( $stylesheet ),
+					),
+					admin_url( 'themes.php' )
+				);
 				$delete_url = wp_nonce_url( $delete_url, 'delete-theme_' . $stylesheet );
 				?>
 				<td><a href="<?php echo esc_url( $delete_url ); ?>" class="button delete-theme"><?php _e( 'Delete' ); ?></a></td>
@@ -343,13 +384,16 @@ $can_install = current_user_can( 'install_themes' );
 
 			if ( $can_install && 'theme_no_parent' === $broken_theme->errors()->get_error_code() ) {
 				$parent_theme_name = $broken_theme->get( 'Template' );
-				$parent_theme = themes_api( 'theme_information', array( 'slug' => urlencode( $parent_theme_name ) ) );
+				$parent_theme      = themes_api( 'theme_information', array( 'slug' => urlencode( $parent_theme_name ) ) );
 
 				if ( ! is_wp_error( $parent_theme ) ) {
-					$install_url = add_query_arg( array(
-						'action' => 'install-theme',
-						'theme'  => urlencode( $parent_theme_name ),
-					), admin_url( 'update.php' ) );
+					$install_url = add_query_arg(
+						array(
+							'action' => 'install-theme',
+							'theme'  => urlencode( $parent_theme_name ),
+						),
+						admin_url( 'update.php' )
+					);
 					$install_url = wp_nonce_url( $install_url, 'install-theme_' . $parent_theme_name );
 					?>
 					<td><a href="<?php echo esc_url( $install_url ); ?>" class="button install-theme"><?php _e( 'Install Parent Theme' ); ?></a></td>
@@ -362,7 +406,7 @@ $can_install = current_user_can( 'install_themes' );
 </table>
 </div>
 
-<?php
+	<?php
 }
 ?>
 </div><!-- .wrap -->
@@ -397,36 +441,38 @@ $can_install = current_user_can( 'install_themes' );
 		?>
 	</div>
 
-	<# if ( data.active ) { #>
-		<h2 class="theme-name" id="{{ data.id }}-name">
-			<?php
-			/* translators: %s: Theme name */
-			printf( __( '<span>Active:</span> %s' ), '{{{ data.name }}}' );
-			?>
-		</h2>
-	<# } else { #>
-		<h2 class="theme-name" id="{{ data.id }}-name">{{{ data.name }}}</h2>
-	<# } #>
-
-	<div class="theme-actions">
+	<div class="theme-id-container">
 		<# if ( data.active ) { #>
-			<# if ( data.actions.customize ) { #>
-				<a class="button button-primary customize load-customize hide-if-no-customize" href="{{{ data.actions.customize }}}"><?php _e( 'Customize' ); ?></a>
-			<# } #>
+			<h2 class="theme-name" id="{{ data.id }}-name">
+				<?php
+				/* translators: %s: Theme name */
+				printf( __( '<span>Active:</span> %s' ), '{{{ data.name }}}' );
+				?>
+			</h2>
 		<# } else { #>
-			<?php
-			/* translators: %s: Theme name */
-			$aria_label = sprintf( _x( 'Activate %s', 'theme' ), '{{ data.name }}' );
-			?>
-			<a class="button activate" href="{{{ data.actions.activate }}}" aria-label="<?php echo $aria_label; ?>"><?php _e( 'Activate' ); ?></a>
-			<a class="button button-primary load-customize hide-if-no-customize" href="{{{ data.actions.customize }}}"><?php _e( 'Live Preview' ); ?></a>
+			<h2 class="theme-name" id="{{ data.id }}-name">{{{ data.name }}}</h2>
 		<# } #>
+
+		<div class="theme-actions">
+			<# if ( data.active ) { #>
+				<# if ( data.actions.customize ) { #>
+					<a class="button button-primary customize load-customize hide-if-no-customize" href="{{{ data.actions.customize }}}"><?php _e( 'Customize' ); ?></a>
+				<# } #>
+			<# } else { #>
+				<?php
+				/* translators: %s: Theme name */
+				$aria_label = sprintf( _x( 'Activate %s', 'theme' ), '{{ data.name }}' );
+				?>
+				<a class="button activate" href="{{{ data.actions.activate }}}" aria-label="<?php echo $aria_label; ?>"><?php _e( 'Activate' ); ?></a>
+				<a class="button button-primary load-customize hide-if-no-customize" href="{{{ data.actions.customize }}}"><?php _e( 'Live Preview' ); ?></a>
+			<# } #>
+		</div>
 	</div>
 </script>
 
 <script id="tmpl-theme-single" type="text/template">
 	<div class="theme-backdrop"></div>
-	<div class="theme-wrap wp-clearfix">
+	<div class="theme-wrap wp-clearfix" role="document">
 		<div class="theme-header">
 			<button class="left dashicons dashicons-no"><span class="screen-reader-text"><?php _e( 'Show previous theme' ); ?></span></button>
 			<button class="right dashicons dashicons-no"><span class="screen-reader-text"><?php _e( 'Show next theme' ); ?></span></button>
@@ -494,8 +540,12 @@ wp_print_request_filesystem_credentials_modal();
 wp_print_admin_notice_templates();
 wp_print_update_row_templates();
 
-wp_localize_script( 'updates', '_wpUpdatesItemCounts', array(
-	'totals'  => wp_get_update_data(),
-) );
+wp_localize_script(
+	'updates',
+	'_wpUpdatesItemCounts',
+	array(
+		'totals' => wp_get_update_data(),
+	)
+);
 
 require( ABSPATH . 'wp-admin/admin-footer.php' );
