@@ -33,19 +33,18 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 *
 	 * @since 3.5.0
 	 *
-	 * @static
-	 *
 	 * @param array $args
 	 * @return bool
 	 */
 	public static function test( $args = array() ) {
-		if ( ! extension_loaded('gd') || ! function_exists('gd_info') )
+		if ( ! extension_loaded( 'gd' ) || ! function_exists( 'gd_info' ) ) {
 			return false;
+		}
 
 		// On some setups GD library does not provide imagerotate() - Ticket #11536
 		if ( isset( $args['methods'] ) &&
-			 in_array( 'rotate', $args['methods'] ) &&
-			 ! function_exists('imagerotate') ){
+			in_array( 'rotate', $args['methods'] ) &&
+			! function_exists( 'imagerotate' ) ) {
 
 				return false;
 		}
@@ -58,20 +57,18 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 *
 	 * @since 3.5.0
 	 *
-	 * @static
-	 *
 	 * @param string $mime_type
 	 * @return bool
 	 */
 	public static function supports_mime_type( $mime_type ) {
 		$image_types = imagetypes();
-		switch( $mime_type ) {
+		switch ( $mime_type ) {
 			case 'image/jpeg':
-				return ($image_types & IMG_JPG) != 0;
+				return ( $image_types & IMG_JPG ) != 0;
 			case 'image/png':
-				return ($image_types & IMG_PNG) != 0;
+				return ( $image_types & IMG_PNG ) != 0;
 			case 'image/gif':
-				return ($image_types & IMG_GIF) != 0;
+				return ( $image_types & IMG_GIF ) != 0;
 		}
 
 		return false;
@@ -85,23 +82,27 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 * @return bool|WP_Error True if loaded successfully; WP_Error on failure.
 	 */
 	public function load() {
-		if ( $this->image )
+		if ( $this->image ) {
 			return true;
+		}
 
-		if ( ! is_file( $this->file ) && ! preg_match( '|^https?://|', $this->file ) )
-			return new WP_Error( 'error_loading_image', __('File doesn&#8217;t exist?'), $this->file );
+		if ( ! is_file( $this->file ) && ! preg_match( '|^https?://|', $this->file ) ) {
+			return new WP_Error( 'error_loading_image', __( 'File doesn&#8217;t exist?' ), $this->file );
+		}
 
 		// Set artificially high because GD uses uncompressed images in memory.
 		wp_raise_memory_limit( 'image' );
 
 		$this->image = @imagecreatefromstring( file_get_contents( $this->file ) );
 
-		if ( ! is_resource( $this->image ) )
-			return new WP_Error( 'invalid_image', __('File is not an image.'), $this->file );
+		if ( ! is_resource( $this->image ) ) {
+			return new WP_Error( 'invalid_image', __( 'File is not an image.' ), $this->file );
+		}
 
 		$size = @getimagesize( $this->file );
-		if ( ! $size )
-			return new WP_Error( 'invalid_image', __('Could not read image size.'), $this->file );
+		if ( ! $size ) {
+			return new WP_Error( 'invalid_image', __( 'Could not read image size.' ), $this->file );
+		}
 
 		if ( function_exists( 'imagealphablending' ) && function_exists( 'imagesavealpha' ) ) {
 			imagealphablending( $this->image, false );
@@ -124,11 +125,13 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 * @return true
 	 */
 	protected function update_size( $width = false, $height = false ) {
-		if ( ! $width )
+		if ( ! $width ) {
 			$width = imagesx( $this->image );
+		}
 
-		if ( ! $height )
+		if ( ! $height ) {
 			$height = imagesy( $this->image );
+		}
 
 		return parent::update_size( $width, $height );
 	}
@@ -149,8 +152,9 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 * @return true|WP_Error
 	 */
 	public function resize( $max_w, $max_h, $crop = false ) {
-		if ( ( $this->size['width'] == $max_w ) && ( $this->size['height'] == $max_h ) )
+		if ( ( $this->size['width'] == $max_w ) && ( $this->size['height'] == $max_h ) ) {
 			return true;
+		}
 
 		$resized = $this->_resize( $max_w, $max_h, $crop );
 
@@ -159,14 +163,14 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 			$this->image = $resized;
 			return true;
 
-		} elseif ( is_wp_error( $resized ) )
+		} elseif ( is_wp_error( $resized ) ) {
 			return $resized;
+		}
 
-		return new WP_Error( 'image_resize_error', __('Image resize failed.'), $this->file );
+		return new WP_Error( 'image_resize_error', __( 'Image resize failed.' ), $this->file );
 	}
 
 	/**
-	 *
 	 * @param int $max_w
 	 * @param int $max_h
 	 * @param bool|array $crop
@@ -175,7 +179,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	protected function _resize( $max_w, $max_h, $crop = false ) {
 		$dims = image_resize_dimensions( $this->size['width'], $this->size['height'], $max_w, $max_h, $crop );
 		if ( ! $dims ) {
-			return new WP_Error( 'error_getting_dimensions', __('Could not calculate resized image dimensions'), $this->file );
+			return new WP_Error( 'error_getting_dimensions', __( 'Could not calculate resized image dimensions' ), $this->file );
 		}
 		list( $dst_x, $dst_y, $src_x, $src_y, $dst_w, $dst_h, $src_w, $src_h ) = $dims;
 
@@ -187,7 +191,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 			return $resized;
 		}
 
-		return new WP_Error( 'image_resize_error', __('Image resize failed.'), $this->file );
+		return new WP_Error( 'image_resize_error', __( 'Image resize failed.' ), $this->file );
 	}
 
 	/**
@@ -213,7 +217,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 * @return array An array of resized images' metadata by size.
 	 */
 	public function multi_resize( $sizes ) {
-		$metadata = array();
+		$metadata  = array();
 		$orig_size = $this->size;
 
 		foreach ( $sizes as $size => $size_data ) {
@@ -232,7 +236,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 				$size_data['crop'] = false;
 			}
 
-			$image = $this->_resize( $size_data['width'], $size_data['height'], $size_data['crop'] );
+			$image     = $this->_resize( $size_data['width'], $size_data['height'], $size_data['crop'] );
 			$duplicate = ( ( $orig_size['width'] == $size_data['width'] ) && ( $orig_size['height'] == $size_data['height'] ) );
 
 			if ( ! is_wp_error( $image ) && ! $duplicate ) {
@@ -242,7 +246,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 
 				if ( ! is_wp_error( $resized ) && $resized ) {
 					unset( $resized['path'] );
-					$metadata[$size] = $resized;
+					$metadata[ $size ] = $resized;
 				}
 			}
 
@@ -269,10 +273,12 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	public function crop( $src_x, $src_y, $src_w, $src_h, $dst_w = null, $dst_h = null, $src_abs = false ) {
 		// If destination width/height isn't specified, use same as
 		// width/height from source.
-		if ( ! $dst_w )
+		if ( ! $dst_w ) {
 			$dst_w = $src_w;
-		if ( ! $dst_h )
+		}
+		if ( ! $dst_h ) {
 			$dst_h = $src_h;
+		}
 
 		$dst = wp_imagecreatetruecolor( $dst_w, $dst_h );
 
@@ -281,8 +287,9 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 			$src_h -= $src_y;
 		}
 
-		if ( function_exists( 'imageantialias' ) )
+		if ( function_exists( 'imageantialias' ) ) {
 			imageantialias( $dst, true );
+		}
 
 		imagecopyresampled( $dst, $this->image, 0, 0, $src_x, $src_y, $dst_w, $dst_h, $src_w, $src_h );
 
@@ -293,7 +300,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 			return true;
 		}
 
-		return new WP_Error( 'image_crop_error', __('Image crop failed.'), $this->file );
+		return new WP_Error( 'image_crop_error', __( 'Image crop failed.' ), $this->file );
 	}
 
 	/**
@@ -306,9 +313,9 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 * @return true|WP_Error
 	 */
 	public function rotate( $angle ) {
-		if ( function_exists('imagerotate') ) {
+		if ( function_exists( 'imagerotate' ) ) {
 			$transparency = imagecolorallocatealpha( $this->image, 255, 255, 255, 127 );
-			$rotated = imagerotate( $this->image, $angle, $transparency );
+			$rotated      = imagerotate( $this->image, $angle, $transparency );
 
 			if ( is_resource( $rotated ) ) {
 				imagealphablending( $rotated, true );
@@ -319,7 +326,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 				return true;
 			}
 		}
-		return new WP_Error( 'image_rotate_error', __('Image rotate failed.'), $this->file );
+		return new WP_Error( 'image_rotate_error', __( 'Image rotate failed.' ), $this->file );
 	}
 
 	/**
@@ -327,18 +334,18 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 *
 	 * @since 3.5.0
 	 *
-	 * @param bool $horz Flip along Horizontal Axis
-	 * @param bool $vert Flip along Vertical Axis
+	 * @param bool $horz Flip along Horizontal Axis.
+	 * @param bool $vert Flip along Vertical Axis.
 	 * @return true|WP_Error
 	 */
 	public function flip( $horz, $vert ) {
-		$w = $this->size['width'];
-		$h = $this->size['height'];
+		$w   = $this->size['width'];
+		$h   = $this->size['height'];
 		$dst = wp_imagecreatetruecolor( $w, $h );
 
 		if ( is_resource( $dst ) ) {
-			$sx = $vert ? ($w - 1) : 0;
-			$sy = $horz ? ($h - 1) : 0;
+			$sx = $vert ? ( $w - 1 ) : 0;
+			$sy = $horz ? ( $h - 1 ) : 0;
 			$sw = $vert ? -$w : $w;
 			$sh = $horz ? -$h : $h;
 
@@ -348,7 +355,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 				return true;
 			}
 		}
-		return new WP_Error( 'image_flip_error', __('Image flip failed.'), $this->file );
+		return new WP_Error( 'image_flip_error', __( 'Image flip failed.' ), $this->file );
 	}
 
 	/**
@@ -364,7 +371,7 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 		$saved = $this->_save( $this->image, $filename, $mime_type );
 
 		if ( ! is_wp_error( $saved ) ) {
-			$this->file = $saved['path'];
+			$this->file      = $saved['path'];
 			$this->mime_type = $saved['mime-type'];
 		}
 
@@ -380,31 +387,33 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	protected function _save( $image, $filename = null, $mime_type = null ) {
 		list( $filename, $extension, $mime_type ) = $this->get_output_format( $filename, $mime_type );
 
-		if ( ! $filename )
+		if ( ! $filename ) {
 			$filename = $this->generate_filename( null, null, $extension );
+		}
 
 		if ( 'image/gif' == $mime_type ) {
-			if ( ! $this->make_image( $filename, 'imagegif', array( $image, $filename ) ) )
-				return new WP_Error( 'image_save_error', __('Image Editor Save Failed') );
-		}
-		elseif ( 'image/png' == $mime_type ) {
+			if ( ! $this->make_image( $filename, 'imagegif', array( $image, $filename ) ) ) {
+				return new WP_Error( 'image_save_error', __( 'Image Editor Save Failed' ) );
+			}
+		} elseif ( 'image/png' == $mime_type ) {
 			// convert from full colors to index colors, like original PNG.
-			if ( function_exists('imageistruecolor') && ! imageistruecolor( $image ) )
+			if ( function_exists( 'imageistruecolor' ) && ! imageistruecolor( $image ) ) {
 				imagetruecolortopalette( $image, false, imagecolorstotal( $image ) );
+			}
 
-			if ( ! $this->make_image( $filename, 'imagepng', array( $image, $filename ) ) )
-				return new WP_Error( 'image_save_error', __('Image Editor Save Failed') );
-		}
-		elseif ( 'image/jpeg' == $mime_type ) {
-			if ( ! $this->make_image( $filename, 'imagejpeg', array( $image, $filename, $this->get_quality() ) ) )
-				return new WP_Error( 'image_save_error', __('Image Editor Save Failed') );
-		}
-		else {
-			return new WP_Error( 'image_save_error', __('Image Editor Save Failed') );
+			if ( ! $this->make_image( $filename, 'imagepng', array( $image, $filename ) ) ) {
+				return new WP_Error( 'image_save_error', __( 'Image Editor Save Failed' ) );
+			}
+		} elseif ( 'image/jpeg' == $mime_type ) {
+			if ( ! $this->make_image( $filename, 'imagejpeg', array( $image, $filename, $this->get_quality() ) ) ) {
+				return new WP_Error( 'image_save_error', __( 'Image Editor Save Failed' ) );
+			}
+		} else {
+			return new WP_Error( 'image_save_error', __( 'Image Editor Save Failed' ) );
 		}
 
 		// Set correct file permissions
-		$stat = stat( dirname( $filename ) );
+		$stat  = stat( dirname( $filename ) );
 		$perms = $stat['mode'] & 0000666; //same permissions as parent folder, strip off the executable bits
 		@ chmod( $filename, $perms );
 
@@ -459,8 +468,9 @@ class WP_Image_Editor_GD extends WP_Image_Editor {
 	 * @return bool
 	 */
 	protected function make_image( $filename, $function, $arguments ) {
-		if ( wp_is_stream( $filename ) )
+		if ( wp_is_stream( $filename ) ) {
 			$arguments[1] = null;
+		}
 
 		return parent::make_image( $filename, $function, $arguments );
 	}
