@@ -1,5 +1,7 @@
 /*
  * Script run inside a Customizer preview frame.
+ *
+ * @output wp-includes/js/customize-preview.js
  */
 (function( exports, $ ){
 	var api = wp.customize,
@@ -36,6 +38,9 @@
 			newQueryParams = api.utils.parseQueryString( urlParser.search.substr( 1 ) );
 
 			newQueryParams.customize_changeset_uuid = oldQueryParams.customize_changeset_uuid;
+			if ( oldQueryParams.customize_autosaved ) {
+				newQueryParams.customize_autosaved = 'on';
+			}
 			if ( oldQueryParams.customize_theme ) {
 				newQueryParams.customize_theme = oldQueryParams.customize_theme;
 			}
@@ -87,12 +92,15 @@
 	};
 
 	/**
+	 * @memberOf wp.customize
+	 * @alias wp.customize.Preview
+	 *
 	 * @constructor
 	 * @augments wp.customize.Messenger
 	 * @augments wp.customize.Class
 	 * @mixes wp.customize.Events
 	 */
-	api.Preview = api.Messenger.extend({
+	api.Preview = api.Messenger.extend(/** @lends wp.customize.Preview.prototype */{
 		/**
 		 * @param {object} params  - Parameters to configure the messenger.
 		 * @param {object} options - Extend any instance parameter or method with this object.
@@ -229,7 +237,7 @@
 	 * @returns {void}
 	 */
 	api.addLinkPreviewing = function addLinkPreviewing() {
-		var linkSelectors = 'a[href], area';
+		var linkSelectors = 'a[href], area[href]';
 
 		// Inject links into initial document.
 		$( document.body ).find( linkSelectors ).each( function() {
@@ -327,15 +335,20 @@
 	 * @returns {void}
 	 */
 	api.prepareLinkPreview = function prepareLinkPreview( element ) {
-		var queryParams;
+		var queryParams, $element = $( element );
+
+        // Skip elements with no href attribute. Check first to avoid more expensive checks down the road
+        if ( ! element.hasAttribute( 'href' ) ) {
+            return;
+        }
 
 		// Skip links in admin bar.
-		if ( $( element ).closest( '#wpadminbar' ).length ) {
+		if ( $element.closest( '#wpadminbar' ).length ) {
 			return;
 		}
 
 		// Ignore links with href="#", href="#id", or non-HTTP protocols (e.g. javascript: and mailto:).
-		if ( '#' === $( element ).attr( 'href' ).substr( 0, 1 ) || ! /^https?:$/.test( element.protocol ) ) {
+		if ( '#' === $element.attr( 'href' ).substr( 0, 1 ) || ! /^https?:$/.test( element.protocol ) ) {
 			return;
 		}
 
@@ -344,18 +357,26 @@
 			element.protocol = 'https:';
 		}
 
+		// Ignore links with class wp-playlist-caption
+		if ( $element.hasClass( 'wp-playlist-caption' ) ) {
+			return;
+		}
+
 		if ( ! api.isLinkPreviewable( element ) ) {
 
 			// Style link as unpreviewable only if previewing in iframe; if previewing on frontend, links will be allowed to work normally.
 			if ( api.settings.channel ) {
-				$( element ).addClass( 'customize-unpreviewable' );
+				$element.addClass( 'customize-unpreviewable' );
 			}
 			return;
 		}
-		$( element ).removeClass( 'customize-unpreviewable' );
+		$element.removeClass( 'customize-unpreviewable' );
 
 		queryParams = api.utils.parseQueryString( element.search.substring( 1 ) );
 		queryParams.customize_changeset_uuid = api.settings.changeset.uuid;
+		if ( api.settings.changeset.autosaved ) {
+			queryParams.customize_autosaved = 'on';
+		}
 		if ( ! api.settings.theme.active ) {
 			queryParams.customize_theme = api.settings.theme.stylesheet;
 		}
@@ -363,11 +384,6 @@
 			queryParams.customize_messenger_channel = api.settings.channel;
 		}
 		element.search = $.param( queryParams );
-
-		// Prevent links from breaking out of preview iframe.
-		if ( api.settings.channel ) {
-			element.target = '_self';
-		}
 	};
 
 	/**
@@ -431,9 +447,16 @@
 
 			// Include customized state query params in URL.
 			queryParams.customize_changeset_uuid = api.settings.changeset.uuid;
+			if ( api.settings.changeset.autosaved ) {
+				queryParams.customize_autosaved = 'on';
+			}
 			if ( ! api.settings.theme.active ) {
 				queryParams.customize_theme = api.settings.theme.stylesheet;
 			}
+
+			// Ensure preview nonce is included with every customized request, to allow post data to be read.
+			queryParams.customize_preview_nonce = api.settings.nonce.preview;
+
 			urlParser.search = $.param( queryParams );
 			options.url = urlParser.href;
 		};
@@ -508,6 +531,9 @@
 		$( form ).removeClass( 'customize-unpreviewable' );
 
 		stateParams.customize_changeset_uuid = api.settings.changeset.uuid;
+		if ( api.settings.changeset.autosaved ) {
+			stateParams.customize_autosaved = 'on';
+		}
 		if ( ! api.settings.theme.active ) {
 			stateParams.customize_theme = api.settings.theme.stylesheet;
 		}
@@ -547,7 +573,7 @@
 		var previousPathName = location.pathname,
 			previousQueryString = location.search.substr( 1 ),
 			previousQueryParams = null,
-			stateQueryParams = [ 'customize_theme', 'customize_changeset_uuid', 'customize_messenger_channel' ];
+			stateQueryParams = [ 'customize_theme', 'customize_changeset_uuid', 'customize_messenger_channel', 'customize_autosaved' ];
 
 		return function keepAliveCurrentUrl() {
 			var urlParser, currentQueryParams;
@@ -652,7 +678,7 @@
 	};
 
 	$( function() {
-		var bg, setValue;
+		var bg, setValue, handleUpdatedChangesetUuid;
 
 		api.settings = window._wpCustomizeSettings;
 		if ( ! api.settings ) {
@@ -745,30 +771,59 @@
 			api.preview.send( 'scroll', $( window ).scrollTop() );
 		});
 
+		/**
+		 * Handle update to changeset UUID.
+		 *
+		 * @param {string} uuid - UUID.
+		 * @returns {void}
+		 */
+		handleUpdatedChangesetUuid = function( uuid ) {
+			api.settings.changeset.uuid = uuid;
+
+			// Update UUIDs in links and forms.
+			$( document.body ).find( 'a[href], area[href]' ).each( function() {
+				api.prepareLinkPreview( this );
+			} );
+			$( document.body ).find( 'form' ).each( function() {
+				api.prepareFormPreview( this );
+			} );
+
+			/*
+			 * Replace the UUID in the URL. Note that the wrapped history.replaceState()
+			 * will handle injecting the current api.settings.changeset.uuid into the URL,
+			 * so this is merely to trigger that logic.
+			 */
+			if ( history.replaceState ) {
+				history.replaceState( currentHistoryState, '', location.href );
+			}
+		};
+
+		api.preview.bind( 'changeset-uuid', handleUpdatedChangesetUuid );
+
 		api.preview.bind( 'saved', function( response ) {
-
 			if ( response.next_changeset_uuid ) {
-				api.settings.changeset.uuid = response.next_changeset_uuid;
+				handleUpdatedChangesetUuid( response.next_changeset_uuid );
+			}
+			api.trigger( 'saved', response );
+		} );
 
-				// Update UUIDs in links and forms.
-				$( document.body ).find( 'a[href], area' ).each( function() {
-					api.prepareLinkPreview( this );
-				} );
-				$( document.body ).find( 'form' ).each( function() {
-					api.prepareFormPreview( this );
-				} );
-
-				/*
-				 * Replace the UUID in the URL. Note that the wrapped history.replaceState()
-				 * will handle injecting the current api.settings.changeset.uuid into the URL,
-				 * so this is merely to trigger that logic.
-				 */
-				if ( history.replaceState ) {
-					history.replaceState( currentHistoryState, '', location.href );
-				}
+		// Update the URLs to reflect the fact we've started autosaving.
+		api.preview.bind( 'autosaving', function() {
+			if ( api.settings.changeset.autosaved ) {
+				return;
 			}
 
-			api.trigger( 'saved', response );
+			api.settings.changeset.autosaved = true; // Start deferring to any autosave once changeset is updated.
+
+			$( document.body ).find( 'a[href], area[href]' ).each( function() {
+				api.prepareLinkPreview( this );
+			} );
+			$( document.body ).find( 'form' ).each( function() {
+				api.prepareFormPreview( this );
+			} );
+			if ( history.replaceState ) {
+				history.replaceState( currentHistoryState, '', location.href );
+			}
 		} );
 
 		/*
